# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-18 10:41
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('djangocms_custommenu', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='StyleMenu',
            fields=[
                ('template', models.CharField(choices=[(b'zoom-masonry', 'Zoom masonry'), (b'dropdown-image', 'Dropdown image')], default=b'zoom-masonry', max_length=255, verbose_name='Template')),
                ('classes', models.CharField(blank=True, help_text='Comma separated list of classes to add to the element.', max_length=255)),
                ('cmsplugin_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='djangocms_custommenu_stylemenu', serialize=False, to='cms.CMSPlugin')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-20 21:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_custommenu', '0007_auto_20180220_1247'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stylemenu',
            name='menu_type',
            field=models.CharField(choices=[(b'show_menu', 'Show menu'), (b'show_menu_below_id', 'Show menu below page'), (b'show_sub_menu', 'Show sub menu')], default=b'show_menu', help_text='Check documentation here http://docs.django-cms.org/en/release-3.4.x/reference/navigation.html', max_length=255, verbose_name='Menu type'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='template',
            field=models.CharField(choices=[(b'default', 'Default'), (b'zoom-masonry', 'Zoom masonry'), (b'dropdown-image', 'Dropdown image'), (b'footer-menu-item', 'Footer menu item')], default=b'default', max_length=255, verbose_name='Template'),
        ),
    ]



from django.core.serializers import serialize
from django.db.models.query import QuerySet
import json
from django.template import Library

register = Library()


def jsonify(obj):
    try:
        if isinstance(obj, QuerySet):
            return serialize('json', obj)
        if isinstance(obj, str) or isinstance(obj, unicode):
            obj = json.loads(obj)
    except:
        obj = {"error": "could not perform jsonify"}
    return json.dumps(obj)

register.filter('jsonify', jsonify)



# -*- coding: utf-8 -*-
from django.db import models
from django.conf import settings
from django.utils.encoding import python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _
from cms.models import CMSPlugin


# Add additional choices through the ``settings.py``.
def get_custommenu_templates():
    return [
        ('default', _('Default')),
    ] + getattr(
        settings,
        'DJANGOCMS_CUSTOMMENU_TEMPLATES',
        [],
    )


@python_2_unicode_compatible
class CustomMenu(CMSPlugin):
    menu_type = models.CharField(
        verbose_name=_('Menu type'),
        max_length=255,
        choices=(
            ("show_menu", _("Show menu")),
            ("show_menu_below_id", _("Show menu below page")),
            ("show_sub_menu", _("Show sub menu")),
        ),
        default="show_menu",
        help_text=_(
            "Check documentation here http://docs.django-cms.org/en/"
            "release-3.4.x/reference/navigation.html"),
    )
    template = models.CharField(
        verbose_name=_('Template'),
        choices=get_custommenu_templates(),
        default=get_custommenu_templates()[0][0],
        max_length=255,
    )

    # for show_menu and show_menu_below_id
    root_page = models.ForeignKey(
        "cms.Page",
        verbose_name=_("Root page"),
        blank=True,
        null=True,
        help_text=_("Menu tree starts from this page. "
                    "Warning: selected page MUST have its ID set in "
                    "advanced settings."))
    start_level = models.PositiveSmallIntegerField(
        _("Start level"),
        default=0,
        help_text=_("From which level the navigation should be rendered.")
    )
    end_level = models.PositiveSmallIntegerField(
        _("End level"),
        default=100,
        help_text=_("At which level the navigation tree should stop.")
    )
    extra_inactive = models.PositiveSmallIntegerField(
        _("Extra inactive"),
        default=0,
        help_text=_("How many levels of navigation should be displayed if a "
                    "node is not a direct ancestor or descendant of the "
                    "current active node.")
    )
    extra_active = models.PositiveSmallIntegerField(
        _("Extra active"),
        default=100,
        help_text=_("How many levels of descendants of the currently active "
                    "node should be displayed.")
    )

    # for show_sub_menu
    levels = models.PositiveSmallIntegerField(
        _("Levels"),
        default=100,
        help_text=_("At which level the navigation tree should stop.")
    )
    root_level = models.PositiveSmallIntegerField(
        _("Root level"),
        blank=True,
        null=True,
        help_text=_("At what level, if any, the menu should have its root.")
    )
    nephews = models.PositiveSmallIntegerField(
        _("Nephews"),
        default=100,
        help_text=_("How many levels of nephews (children of siblings) "
                    "are shown.")
    )

    classes = models.CharField(
        blank=True,
        help_text=_("Comma separated list of classes to add to the element."),
        max_length=255,
    )
    configuration = models.TextField(
        blank=True,
        help_text=_('Custom configuration.'),
    )

    def get_menu_template(self):
        return 'djangocms_custommenu/custommenu/{}.html'\
            .format(self.template)

    def get_classes(self):
        return ' '.join(item.strip() for item in self.classes.split(',') if item.strip())

    # Add an app namespace to related_name to avoid field name clashes
    # with any other plugins that have a field with the same name as the
    # lowercase of the class name of this model.
    # https://github.com/divio/django-cms/issues/5030
    cmsplugin_ptr = models.OneToOneField(
        CMSPlugin,
        related_name='%(app_label)s_%(class)s',
        parent_link=True,
    )

    def __str__(self):
        return "Custom menu %s %s %s" % \
            (str(self.pk), self.template,
             self.root_page.get_menu_title() if self.root_page else "")


# Add additional choices through the ``settings.py``.
def get_automenu_templates():
    return [
        ('default', _('Default')),
    ] + getattr(
        settings,
        'DJANGOCMS_CUSTOMMENU_AUTOMENU_TEMPLATES',
        [],
    )


@python_2_unicode_compatible
class AutoMenu(CMSPlugin):
    selector = models.CharField(
        max_length=255,
        verbose_name=_('Selector'),
        help_text=_("Selector for elements that should become anchors.")
    )
    template = models.CharField(
        verbose_name=_('Template'),
        choices=get_automenu_templates(),
        default=get_automenu_templates()[0][0],
        max_length=255,
    )

    # Add an app namespace to related_name to avoid field name clashes
    # with any other plugins that have a field with the same name as the
    # lowercase of the class name of this model.
    # https://github.com/divio/django-cms/issues/5030
    cmsplugin_ptr = models.OneToOneField(
        CMSPlugin,
        related_name='%(app_label)s_%(class)s',
        parent_link=True,
    )

    def __str__(self):
        return "Auto Menu %s" % str(self.pk)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-17 19:55
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
    ]

    operations = [
        migrations.CreateModel(
            name='AutoMenu',
            fields=[
                ('selector', models.CharField(help_text='Selector for elements that should become anchors.', max_length=255, verbose_name='Selector')),
                ('template', models.CharField(choices=[(b'default', 'Default')], default=b'default', max_length=255, verbose_name='Template')),
                ('cmsplugin_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='djangocms_custommenu_automenu', serialize=False, to='cms.CMSPlugin')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from . import models


class CustomMenuPlugin(CMSPluginBase):
    model = models.CustomMenu
    name = _('Custom menu')
    module = _('Custom menu')
    render_template = 'djangocms_custommenu/custommenu/base.html'

    fieldsets = [
        (None, {
            'description': _(
                "Check documentation here http://docs.django-cms.org/en/"
                "release-3.4.x/reference/navigation.html"
            ),
            'fields': (
                'menu_type',
                'template',
                'classes',
                'configuration',
            )
        }),
        ("Show menu options", {
            'classes': ('collapse',),
            'fields': (
                'root_page',
                'start_level',
                'end_level',
                'extra_inactive',
                'extra_active',
            )
        }),
        ("Show sub menu options", {
            'classes': ('collapse',),
            'fields': (
                'levels',
                'root_level',
                'nephews',
            )
        }),
    ]


plugin_pool.register_plugin(CustomMenuPlugin)


class AutoMenuPlugin(CMSPluginBase):
    """ Creates in-page anchor (scroll to) menu using javascript. """
    model = models.AutoMenu
    name = _('Auto Menu')
    module = _('Custom menu')

    fieldsets = [
        (None, {
            'fields': (
                'selector',
                'template',
            )
        }),
    ]

    def get_render_template(self, context, instance, placeholder):
        return 'djangocms_custommenu/automenu/{}.html'\
            .format(instance.template)


plugin_pool.register_plugin(AutoMenuPlugin)


class BreadcrumbsPlugin(CMSPluginBase):
    name = _('Breadcrumbs')
    module = _('Custom menu')
    render_template = 'djangocms_custommenu/breadcrumbs/default.html'


plugin_pool.register_plugin(BreadcrumbsPlugin)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-03-04 21:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('djangocms_custommenu', '0009_custommenu'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='stylemenu',
            name='cmsplugin_ptr',
        ),
        migrations.RemoveField(
            model_name='stylemenu',
            name='root_page',
        ),
        migrations.DeleteModel(
            name='StyleMenu',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-18 16:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_custommenu', '0002_stylemenu'),
    ]

    operations = [
        migrations.AddField(
            model_name='stylemenu',
            name='configuration',
            field=models.TextField(blank=True, help_text='Custom configuration.'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-20 11:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_custommenu', '0006_auto_20180220_1039'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stylemenu',
            name='template',
            field=models.CharField(choices=[(b'default', 'Default'), (b'zoom-masonry', 'Zoom masonry'), (b'dropdown-image', 'Dropdown image')], default=b'default', max_length=255, verbose_name='Template'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-20 08:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_custommenu', '0004_auto_20180220_0908'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stylemenu',
            name='end_level',
            field=models.PositiveSmallIntegerField(default=100, help_text='At which level the navigation tree should stop.', verbose_name='End level'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='extra_active',
            field=models.PositiveSmallIntegerField(default=100, help_text='How many levels of descendants of the currently active node should be displayed.', verbose_name='Extra active'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='extra_inactive',
            field=models.PositiveSmallIntegerField(default=0, help_text='How many levels of navigation should be displayed if a node is not a direct ancestor or descendant of the current active node.', verbose_name='Extra inactive'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='levels',
            field=models.PositiveSmallIntegerField(default=100, help_text='At which level the navigation tree should stop.', verbose_name='Levels'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='nephews',
            field=models.PositiveSmallIntegerField(default=100, help_text='How many levels of nephews (children of siblings) are shown.', verbose_name='Nephews'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='root_level',
            field=models.PositiveSmallIntegerField(blank=True, help_text='At what level, if any, the menu should have its root.', null=True, verbose_name='Root level'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='start_level',
            field=models.PositiveSmallIntegerField(default=0, help_text='From which level the navigation should be rendered.', verbose_name='Start level'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-20 09:39
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangocms_custommenu', '0005_auto_20180220_0912'),
    ]

    operations = [
        migrations.AlterField(
            model_name='stylemenu',
            name='menu_type',
            field=models.CharField(choices=[(b'show_menu', 'Show menu'), (b'show_sub_menu', 'Show sub menu')], default=b'show_menu', help_text='Check documentation here http://docs.django-cms.org/en/release-3.4.x/reference/navigation.html', max_length=255, verbose_name='Menu type'),
        ),
        migrations.AlterField(
            model_name='stylemenu',
            name='root_page',
            field=models.ForeignKey(blank=True, help_text='Menu tree starts from this page. Warning: selected page MUST have its ID set in advanced settings.', null=True, on_delete=django.db.models.deletion.CASCADE, to='cms.Page', verbose_name='Root page'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-03-04 21:21
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('djangocms_custommenu', '0008_auto_20180220_2242'),
    ]

    operations = [
        migrations.CreateModel(
            name='CustomMenu',
            fields=[
                ('menu_type', models.CharField(choices=[(b'show_menu', 'Show menu'), (b'show_menu_below_id', 'Show menu below page'), (b'show_sub_menu', 'Show sub menu')], default=b'show_menu', help_text='Check documentation here http://docs.django-cms.org/en/release-3.4.x/reference/navigation.html', max_length=255, verbose_name='Menu type')),
                ('template', models.CharField(choices=[(b'default', 'Default'), (b'zoom-masonry', 'Zoom masonry'), (b'dropdown-image', 'Dropdown image'), (b'footer-menu-item', 'Footer menu item')], default=b'default', max_length=255, verbose_name='Template')),
                ('start_level', models.PositiveSmallIntegerField(default=0, help_text='From which level the navigation should be rendered.', verbose_name='Start level')),
                ('end_level', models.PositiveSmallIntegerField(default=100, help_text='At which level the navigation tree should stop.', verbose_name='End level')),
                ('extra_inactive', models.PositiveSmallIntegerField(default=0, help_text='How many levels of navigation should be displayed if a node is not a direct ancestor or descendant of the current active node.', verbose_name='Extra inactive')),
                ('extra_active', models.PositiveSmallIntegerField(default=100, help_text='How many levels of descendants of the currently active node should be displayed.', verbose_name='Extra active')),
                ('levels', models.PositiveSmallIntegerField(default=100, help_text='At which level the navigation tree should stop.', verbose_name='Levels')),
                ('root_level', models.PositiveSmallIntegerField(blank=True, help_text='At what level, if any, the menu should have its root.', null=True, verbose_name='Root level')),
                ('nephews', models.PositiveSmallIntegerField(default=100, help_text='How many levels of nephews (children of siblings) are shown.', verbose_name='Nephews')),
                ('classes', models.CharField(blank=True, help_text='Comma separated list of classes to add to the element.', max_length=255)),
                ('configuration', models.TextField(blank=True, help_text='Custom configuration.')),
                ('cmsplugin_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='djangocms_custommenu_custommenu', serialize=False, to='cms.CMSPlugin')),
                ('root_page', models.ForeignKey(blank=True, help_text='Menu tree starts from this page. Warning: selected page MUST have its ID set in advanced settings.', null=True, on_delete=django.db.models.deletion.CASCADE, to='cms.Page', verbose_name='Root page')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-02-20 08:08
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20160608_1535'),
        ('djangocms_custommenu', '0003_stylemenu_configuration'),
    ]

    operations = [
        migrations.AddField(
            model_name='stylemenu',
            name='end_level',
            field=models.IntegerField(default=100, help_text='At which level the navigation tree should stop.', verbose_name='End level'),
        ),
        migrations.AddField(
            model_name='stylemenu',
            name='extra_active',
            field=models.IntegerField(default=100, help_text='How many levels of descendants of the currently active node should be displayed.', verbose_name='Extra active'),
        ),
        migrations.AddField(
            model_name='stylemenu',
            name='extra_inactive',
            field=models.IntegerField(default=0, help_text='How many levels of navigation should be displayed if a node is not a direct ancestor or descendant of the current active node.', verbose_name='Extra inactive'),
        ),
        migrations.AddField(
            model_name='stylemenu',
            name='levels',
            field=models.IntegerField(default=100, help_text='At which level the navigation tree should stop.', verbose_name='Levels'),
        ),
        migrations.AddField(
            model_name='stylemenu',
            name='menu_type',
            field=models.CharField(choices=[(b'show_menu', 'Show menu'), (b'show_sub_menu', 'Show sub menu')], default=b'show_menu', help_text='Check documentation here http://docs.django-cms.org/en/release-3.4.x/reference/navigation.html', max_length=255, verbose_name='Template'),
        ),
        migrations.AddField(
            model_name='stylemenu',
            name='nephews',
            field=models.IntegerField(default=100, help_text='How many levels of nephews (children of siblings) are shown.', verbose_name='Nephews'),
        ),
        migrations.AddField(
            model_name='stylemenu',
            name='root_level',
            field=models.IntegerField(blank=True, help_text='At what level, if any, the menu should have its root.', null=True, verbose_name='Root level'),
        ),
        migrations.AddField(
            model_name='stylemenu',
            name='root_page',
            field=models.ForeignKey(default=1, help_text='Menu tree starts from this page.', on_delete=django.db.models.deletion.CASCADE, to='cms.Page', verbose_name='Root page'),
        ),
        migrations.AddField(
            model_name='stylemenu',
            name='start_level',
            field=models.IntegerField(default=0, help_text='From which level the navigation should be rendered.', verbose_name='Start level'),
        ),
    ]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import find_packages, setup

from djangocms_custommenu import __version__


REQUIREMENTS = [
    'django-cms>=3.3.1',
    'djangocms-attributes-field>=0.1.1',
]


CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Topic :: Internet :: WWW/HTTP',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Software Development :: Libraries :: Application Frameworks',
    'Topic :: Software Development :: Libraries :: Python Modules',
]


setup(
    name='djangocms-custommenu',
    version=__version__,
    description=('Adds custom menu plugin to django CMS.'),
    author='Damir Arbula',
    author_email='damir.arbula@gmail.com',
    url='https://github.com/darbula/djangocms-custommenu',
    license='BSD',
    long_description=open('README.rst').read(),
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=REQUIREMENTS,
    classifiers=CLASSIFIERS,
    # test_suite='tests.settings.run',
)
